﻿Imports System.Collections.Generic
Imports System.Collections.ObjectModel
Imports ThinkGeo.MapSuite.Core

Public Class cNettroMiniMapLayer

  Inherits AdornmentLayer
  Private m_layers As Collection(Of Layer)
  Private m_width As Integer
  Private m_height As Integer

  Public Sub New()
    Me.New(New Layer() {}, 100, 100)
  End Sub

  Public Sub New(width As Integer, height As Integer)
    Me.New(New Layer() {}, width, height)
  End Sub

  Public Sub New(layers As IEnumerable(Of Layer), width As Integer, height As Integer)
    Me.m_layers = New Collection(Of Layer)()
    For Each layer As Layer In layers
      Me.m_layers.Add(layer)
    Next

    Me.m_width = width
    Me.m_height = height
  End Sub

  Public ReadOnly Property Layers() As Collection(Of Layer)
    Get
      Return m_layers
    End Get
  End Property

  Public Property Width() As Integer
    Get
      Return m_width
    End Get
    Set(value As Integer)
      m_width = value
    End Set
  End Property

  Public Property Height() As Integer
    Get
      Return m_height
    End Get
    Set(value As Integer)
      m_height = value
    End Set
  End Property

  Protected Overrides Sub DrawCore(canvas As GeoCanvas, labelsInAllLayers As Collection(Of SimpleCandidate))

    Dim miniImage As New Bitmap(m_width, m_height)
    Dim scaledWorldExtent As RectangleShape = MapEngine.GetDrawingExtent(canvas.CurrentWorldExtent, m_width, m_height)

    scaledWorldExtent.ScaleUp(300)

    Dim minCanvas As New GdiPlusGeoCanvas()

    minCanvas.BeginDrawing(miniImage, scaledWorldExtent, canvas.MapUnit)
    For Each layer As Layer In m_layers
      layer.Draw(minCanvas, labelsInAllLayers)
    Next

    minCanvas.DrawArea(RectangleShape.ScaleDown(minCanvas.CurrentWorldExtent, 1), New GeoPen(GeoColor.StandardColors.Gray, 2), DrawingLevel.LevelOne)
    minCanvas.DrawArea(canvas.CurrentWorldExtent, New GeoPen(GeoColor.StandardColors.Black, 2), DrawingLevel.LevelOne)

    minCanvas.EndDrawing()

    Dim drawingLocation As ScreenPointF = GetDrawingLocation(canvas, m_width, m_height)

    Dim oMemStream As New System.IO.MemoryStream

    miniImage.Save(oMemStream, Drawing.Imaging.ImageFormat.Bmp)
    Dim oGeoImage = New GeoImage(oMemStream)

    canvas.DrawScreenImageWithoutScaling(oGeoImage, (drawingLocation.X + m_width \ 2) + 10, (drawingLocation.Y + m_height \ 2) - 10, DrawingLevel.LevelOne, 0, 0, _
      0)
  End Sub
End Class
